ty.template


processclj

(process source-file target-file)
(process source-file target-file variables)

Process a template file by replacing {{variable}} placeholders with provided values. Reads from resources or file system and writes to target path.

Process a template file by replacing {{variable}} placeholders with provided values.
Reads from resources or file system and writes to target path.
sourceraw docstring

random-stringclj

(random-string)
(random-string length)

Generate a random string of specified length for cache-busting

Generate a random string of specified length for cache-busting
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries